# Crosstalent Connector
> Crosstalent designs and implements innovative solutions for human resources management.

🔗 https://www.crosstalent.eu/fr/

| Actions |
| ------- |
| [**Pull jobs**](docs/pull_jobs.md) |
| [**Push profile**](docs/push_profile.md) |